@@ -34,7 +34,10 @@ from .saml_clients.saml_client_factory import SAMLClientFactory
 
 
 F = TypeVar("F", bound=Callable[..., Any])
-PROD_MODE = os.getenv("SENTRY_ENVIRONMENT") != "development" and os.getenv("CI") != "true"
+
+
+def is_prod_mode():
+    return os.getenv("SENTRY_ENVIRONMENT") != "development" and os.getenv("CI") != "true"
 
 
 def run_subprocess(
@@ -211,7 +214,7 @@ def skip_analytics(fn: F) -> F:
 
 
 def setup_segment(**kwargs: Any) -> Callable[[F], F]:
-    analytics.default_client = analytics.client.Client(send=PROD_MODE, **kwargs)
+    analytics.default_client = analytics.client.Client(send=is_prod_mode(), **kwargs)
 
     def decorator(fn: F) -> F:
         @click.pass_context
@@ -226,8 +229,8 @@ def setup_segment(**kwargs: Any) -> Callable[[F], F]:
 
 
 def setup_sentry(**kwargs: Any) -> Callable[[F], F]:
-    environment = "pypi" if PROD_MODE else "development"
-    sample_rate = 1.0 if PROD_MODE else 0.0
+    environment = "pypi" if is_prod_mode() and not Config.is_sym() else "development"
+    sample_rate = 1.0 if is_prod_mode() else 0.0
     sentry_init(environment=environment, sample_rate=sample_rate, **kwargs)
 
     def decorator(fn: F) -> F:
