@@ -109,3 +109,10 @@ class Config(ConfigBase[ConfigSchema]):
                 instance_config["aliases"].append(alias)
             if region:
                 instance_config["region"] = region
+
+    @classmethod
+    def is_sym(cls) -> bool:
+        try:
+            return cls.get_org() == "sym"
+        except KeyError as e:
+            return False
